@@ -143,7 +143,7 @@ if __name__ == '__main__':
 
             # datum...
             now = LocalizedDatetime.now().utc()
-            datum = ControlDatum.construct(tag, cmd.device_tag, now, cmd_tokens, cmd.device_shared_secret)
+            datum = ControlDatum.construct(tag, cmd.device_tag, now, cmd_tokens, cmd.timeout, cmd.device_shared_secret)
 
             publication = Publication(cmd.device_topic, datum)
             handler.set(publication)
@@ -202,11 +202,7 @@ if __name__ == '__main__':
     # end...
 
     except KeyboardInterrupt:
-        if cmd.interactive:
-            print("", file=sys.stderr)
-
-        if cmd.verbose:
-            print("osio_mqtt_control: KeyboardInterrupt", file=sys.stderr)
+        print(file=sys.stderr)
 
     finally:
         if client:
